@@ -312,10 +312,7 @@ class language_learner:
         self.input_text = ''
         self.button_object_list = []
         self.path_source = os.path.join(current_path, "source")
-        # create directory
-        self.report_path = self.generate_new_folder('L_report')
-        self.record_path = self.generate_new_folder('L_record')
-        self.source_path = self.generate_new_folder('L_source')
+
         # self.df = pd.read_csv (data_file,sep = '|')
         # self.df_backup = self.df.copy(deep=True)
         # create widgets
@@ -581,6 +578,7 @@ class language_learner:
                 self.report_dict['correct'][self.problem_index-1] = 1
                 self.button_start.config(background = '#1ecc3f')
                 self.button_record.configure(background="#d9d9d9")
+                self.button_check_callback()
 
         # if self.problem_index>self.rounds_config:
 
@@ -646,7 +644,7 @@ class language_learner:
                                            "It is not bad. You get "+str(similarity)+'. Would you make another try?')
                             if res == 'yes':
                                 self.retry_times +=1
-                                self.button_record_callback()
+                                # self.button_record_callback()
 
                             elif res == 'no':
                                 self.retry_times =0
@@ -654,7 +652,7 @@ class language_learner:
                         elif similarity<=60:
                             messagebox.showinfo('Not OK', "Hmm, You only got "+str(similarity)+'. Please try agagin!')
                             self.retry_times +=1
-                            self.button_record_callback()
+                            # self.button_record_callback()
                     else:
                         messagebox.showinfo('Not OK', 'Hmm, You try too many times, let us skip this')
                         self.retry_times =0
@@ -666,6 +664,7 @@ class language_learner:
                 self.report_dict['correct'][self.problem_index-1] = 0
                 self.button_record.config(background = '#f60505')
                 self.button_start.configure(background="#d9d9d9")
+                self.button_check_callback()
 
     def button_before_callback(self):
         if self.button_before['text'] == 'Before':
@@ -732,11 +731,16 @@ class language_learner:
             self.creat_buttons()
             self.label_word.configure(text='')
 
+
         if self.problem_index == self.rounds_config:
             self.initialize_widgets_for_check_stop()
             self.save_report()
 
         self.problem_index+=1
+        try:
+            self.button_read_callback()
+        except:
+            print('No audio file find!')
         if self.problem_index > self.rounds_config:
             self.problem_index = 0
 
@@ -752,7 +756,7 @@ class language_learner:
             self.rounds_config = int(self.rounds_val.get())
         else:
             self.rounds_val.set(str(0))
-
+        self.delete_privious_buttons()
         self.button_report.config(state= "normal")
 
         self.button_start.config(text = 'OK')
@@ -774,10 +778,10 @@ class language_learner:
         self.rounds_val.set('Rounds')
         self.time_val.set('Timer')
         self.button_report.config(state= "normal")
-        self.entry_timer.config(state= "normal")
-        self.entry_rounds.config(state= "normal")
+        self.entry_timer.config(state= "disabled")
+        self.entry_rounds.config(state= "disabled")
         self.button_start.config(text = 'Start')
-        self.button_start.config(state= "normal")
+        self.button_start.config(state= "disabled")
         self.button_start.configure(background="#d9d9d9")
 
         self.button_record.config(text = 'Record')
@@ -789,8 +793,8 @@ class language_learner:
 
         self.button_check.config(text = 'Check')
         self.button_check.config(state = 'normal')
-
-        self.label_word.config(text = '''Click [Start]''')
+        self.delete_privious_buttons()
+        self.label_word.config(text = '''Click [File]->[Open] to start new learning.''')
 
 
 
@@ -837,6 +841,11 @@ class language_learner:
     def menu_open_callback(self):
         # self.use_database=True
         self.load_csv()
+        # create directory
+        self.report_path = self.generate_new_folder('L_report')
+        self.record_path = self.generate_new_folder('L_record')
+        self.source_path = self.generate_new_folder('L_source')
+
         self.initialize_widgets_for_start()
         self.generate_problem_list_from_database()
         self.problem_index = 0
@@ -867,7 +876,10 @@ class language_learner:
         self.button_before.config(state = 'normal')
 
     def initialize_widgets_for_stop(self):
-        self.thread_time_countdown.raise_exception()
+        try:
+            self.thread_time_countdown.raise_exception()
+        except:
+            print('No no attribute thread_time_countdown')
         self.rounds_val.set('Rounds')
         self.time_val.set('Timer')
         self.button_report.config(state= "normal")
@@ -886,6 +898,7 @@ class language_learner:
         input_text = []
         # os.getcwd()
         path_txt = filedialog.askopenfilename(title = "Select file",filetypes = (("CSV Files","*.csv"),))
+        self.path_csv = path_txt
         try:
             self.df = pd.read_csv (path_txt,sep = '|')
         except:
@@ -893,7 +906,8 @@ class language_learner:
         self.df_backup = self.df.copy(deep=True)
 
     def generate_new_folder(self,folder_name = "L_report"):
-        current_path = os.path.dirname(os.path.abspath(__file__))
+        # current_path = os.path.dirname(os.path.abspath(__file__))
+        current_path = self.path_csv
         if not os.path.isdir(os.path.join(current_path, folder_name)):
             os.mkdir(os.path.join(current_path, folder_name))
         return os.path.join(current_path, folder_name)
